#include <math.h>
#include <stdio.h>
#include <malloc.h>

#define ANL_FILE "analyza"   /* vyst subor analyzy */
#define TAM      1      /* konstanta pre priamu trafo */
#define SPAT     -1     /* konstanta pre spatnu trafo */
#define YMAX     512    /* max Y velkost 2D pola       */
#define D1MAX    1024    /* max dlzka 1D lokalneho pola */
#define MAX1D    1024    /* max dlzka 1D lokalneho pola */
#define NLEN     50     /* max dlzka nazvu suboru */
#define BLMAX    4096   /* pax pocet blokov */
#define CMPMAX   100000 /* max velkost skompresovanych dat */
#define PROCMAX  10     /* max pocet procesov */
#define HUROVNI  1024   /* max pocet urovni ktore idu do huffmana */
#define EUROVNI  4096   /* max pocet urovni pri vypocte entropie  */
#define RMX      32     /* max X velkost nacitavacej matice */
#define RMY      32     /* max Y velkost nacitavacej matice */
#define BLHUFMIN 16     /* Min. pocet blokov aby som JSM kodoval huffmanom*/
#define MAXNAME  80     /* Max dlzka popisu transformacie */
#define MAXDAVKA 50     /* Max pocet transformacii v subore trafo */
#define MAXTABR  10     /* Max dlzka mena trafo v subore trafos */
#define MGAUSS   30     /* Maximum gaussovskych rusiciek v bloku */
#define TWH      1      /* Walsh - Hawamard */
#define TWP      2      /* Walsh - Palley */
#define TWS      3      /* Walsh v sekvencnom usporiadani bazovych funkcii */
#define TSH      4      /* Slant - Hawamard */
#define TSP      5      /* Slant - Palley */ 
#define TSS      6      /* Slant v sekvencnom usporiadani bazovych funkcii */
#define THA      7      /* Haarova transformacia */
#define THY      8      /* Hartleyova transformacia */
#define THYP     9      /* Hartleyova transformacia s preusporiadanim spektra*/
#define TCOS     10     /* Cosinusova transformacia */
#define TF       11     /* Fourierova transformacia */
#define TFP      12     /* Fourierova transformacia s preusporiadanim spektra*/
#define WAV      13     /* Waveletova transformacia standard*/
#define WAN      14     /* Waveletova nestandardne          */
#define WAH      15     /* Waveletova s hilbertovym nacitanim */
#define ppz printf("Vypocet v blokoch:\n")
#define pps(blk) {printf("\b\b\b\b\b%d",blk+1);fflush(stdout);}
#define ppk printf(" blokov OK\n")

/*---------------------  globalne premenne  -------------------*/
/*****************      rusicka                  **************/
struct rusenie        { int  type;                    /*typ rusenia 0=gauss,1=cik-cak*/
                        int   gpx[MGAUSS];                    /* x -ova poloha rusenia */
                        int   gpy[MGAUSS];                    /* y -ova poloha rusenia */
                        float gampl[MGAUSS];                  /* amplituda rusenia */
                        float gtvar[MGAUSS];                  /* tvar zvonu rusenia */
                        float ghran[MGAUSS];                  /* hranica zvonu rusenia */
                        int  numgauss;                        /*pocet gaussovych rusiciek*/
                        float campl,ctvar,chran;              /* ampl,tvar,hran pre cik-cak*/
                        } rus;
/*****************    transformacia               **************/
struct trafo_define   { char txname[MAXNAME];          /* popis act. trafo*/
                        char tyname[MAXNAME];          /* popis act. trafo*/
                        char txabr[MAXTABR];           /* skratka act.trafo X */
                        char tyabr[MAXTABR];           /* skratka act.trafo Y */
                        int  ynum[MAXDAVKA];           /* nacitane z "trafos"*/
                        int  xnum[MAXDAVKA];         /* nacitane z "trafos"*/
                        int  txnum;                 /*act  cislo X trafo */
                        int  tynum;                 /*act  cislo Y trafo */
                        int  allnum;                /*pocet vsetkych trafo */
                        }trdef;
/*****************    predspracovacie procedury   **************/
struct predspracovanie{ int ziv;
			long zlbity;
			int ziv_rov;  /*pocet rovin */
			int ziv_biby; /*pocet bitov Z-L na byty suboru */
			int log ;     /*robit logaritmus ? */
			int rl;       /*robit R-L coding ?*/
			int rl_sl;    /*pocet bitov v slovniku */
			int rl_huf;   /*pocet bitov na 1 vzorku */
			} pred;

/*****************   parametre lin. kvantizatora  **************/
struct l_qnt          { int srob;             /* kvantovat str. zlozky ? */
                        float smax,smin,skr;  /* max,min,krok str. hodnot*/
			int su;               /* pocet urovni spektra*/
			int jrob;             /* kvantovat jsm zlozky ?*/
			float jmax,jmin,jkr;  /* max,min,krok jsm zloziek*/
			int ju;               /* pocet urovni jsm zloziek*/
			}lq;
/****************   parametre nelin. kvantizatora *******/
struct  nl_qnt        { int ako;/*kvantujem aj maticou/filtrujem */
			int mtr;/*transformujem maticu?*/
			char mname[NLEN];
			int vx,vy ; /* velkosti matice v x a y smere */
			int sposob;  /* bud maticou, alebo rucne */
			float min,max; /* bod zaciatku a konca prechodu*/
			float jsm;       /* uprava jsm zlozky */
			}nlq ;
/*****************   parametre robenia uprav **************/
struct praca_v_spektre{ int rus; /* robit rusenie */
			int upr; /* robit upravy  */
			}pvs;
/*****************   struktura na compress subor **************/
struct vyst_cmp_subor { unsigned char *buf;
			unsigned long ptr ;
			int rob;  /*vytvarat bit/bod tj kompresovat ?*/
			char subor[NLEN];
			}comp;
/*******************      naberanie spektra **************************/
struct metoda_zastav  { int cykl; /*spolocne pre vsetky typy naberania*/
			int min,max,krok;
			void (*begin)();  /*pointer na zaciatok  metody*/
			int (*podm)();    /*pointer na podmienku metody*/
			}met;
struct naberanie      { int typ;        /*zadany typ naberania*/
			int method;     /*zadany typ metody zastavenia */
			char m2name[NLEN];/*meno naberacej matice */
			int tam;        /* smer naberanie/obnovovanie */
			void (*rez)();   /*a pointer na naberaci algoritmus*/
			void (*init)();
			}rez;
struct energobnova    { int robit;
			float koef[BLMAX];
			} oberg;
/************************** blokovanie ****************************/
struct blokovanie     { int bx,by;  /* velkost blokov */
			int type;   /* typ blokov */
			long numb;
			int  *data[BLMAX];
			long ldata[BLMAX];
			} bl ;

/******************  parametre normalu *******************/
struct sim_par        { char vstup[NLEN];
			int ox,oy;
			int count;
			float Mse,BnB,odhadbnb,ctcbnb,entropia,shufbnb;
			} sim ;
/******************** uzivatelske prostredie *******************/
struct proc_control   { int pid[PROCMAX],poc_proc;
                        int rus; /*rusit spektra ?*/
                        int upravy;/*robit upravy spektra ?*/
			int spec;/*psign=1 vytvara subory spektier */
			int show; /*show=1 vytvara procesy*/
			int flo;   /*vytvorit float spectrum?*/
			int chname; /*menit mena suborov podla sim.count */
                        int pis;    /* vytvarat vobec nejake vyst. subory ?*/
			} proc ;


